.. highlight:: shell

============
Installation
============

Requirements
------------

Pulsarbat requires:

- **Python 3.8** or later
- `Astropy <https://www.astropy.org/>`_ v4.0 or later
- `Numpy <https://www.numpy.org/>`_ v1.18 or later
- `Scipy <https://scipy.org/>`_ v1.14 or later


Stable release
--------------

To install pulsarbat, run this command in your terminal:

.. code-block:: console

    $ pip install pulsarbat

This is the preferred method to install pulsarbat, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

The sources for pulsarbat can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/theXYZT/pulsarbat

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/theXYZT/pulsarbat/tarball/master

Once you have a copy of the source, you can install it with either:

.. code-block:: console

    $ python setup.py install

or

.. code-block:: console

    $ pip install .


.. _Github repo: https://github.com/theXYZT/pulsarbat
.. _tarball: https://github.com/theXYZT/pulsarbat/tarball/master
